@@ -6,7 +6,7 @@ use Scalar::Util ();
 use Encode ();
 
 package XML::Builder;
-$XML::Builder::VERSION = '0.905';
+$XML::Builder::VERSION = '0.906';
 # ABSTRACT: programmatic XML generation, conveniently
 
 use Object::Tiny::Lvalue qw( nsmap default_ns encoding );
@@ -195,7 +195,7 @@ sub stringify {
 #######################################################################
 
 package XML::Builder::NS;
-$XML::Builder::NS::VERSION = '0.905';
+$XML::Builder::NS::VERSION = '0.906';
 use Object::Tiny::Lvalue qw( builder uri prefix qname_for_localname );
 use overload '""' => 'uri', fallback => 1;
 
@@ -232,7 +232,7 @@ sub factory { bless \shift, 'XML::Builder::NS::QNameFactory' }
 #######################################################################
 
 package XML::Builder::NS::QNameFactory;
-$XML::Builder::NS::QNameFactory::VERSION = '0.905';
+$XML::Builder::NS::QNameFactory::VERSION = '0.906';
 sub AUTOLOAD { my $self = shift; $$self->qname( ( our $AUTOLOAD =~ /.*::(.*)/ ), @_ ) }
 sub _qname   { my $self = shift; $$self->qname(                                  @_ ) }
 sub DESTROY  {}
@@ -240,13 +240,13 @@ sub DESTROY  {}
 #######################################################################
 
 package XML::Builder::Fragment::Role;
-$XML::Builder::Fragment::Role::VERSION = '0.905';
+$XML::Builder::Fragment::Role::VERSION = '0.906';
 sub depends_ns_scope { 1 }
 
 #######################################################################
 
 package XML::Builder::Fragment;
-$XML::Builder::Fragment::VERSION = '0.905';
+$XML::Builder::Fragment::VERSION = '0.906';
 use parent -norequire => 'XML::Builder::Fragment::Role';
 
 use Object::Tiny::Lvalue qw( builder content );
@@ -265,7 +265,7 @@ sub new {
 		@take = $r;
 
 		if ( not Scalar::Util::blessed $r ) {
-			@take = $builder->render( @_ ) if 'ARRAY' eq ref $r;
+			@take = $builder->render( @$r ) if 'ARRAY' eq ref $r;
 			next;
 		}
 
@@ -315,7 +315,7 @@ sub flatten {
 #######################################################################
 
 package XML::Builder::Fragment::Unsafe;
-$XML::Builder::Fragment::Unsafe::VERSION = '0.905';
+$XML::Builder::Fragment::Unsafe::VERSION = '0.906';
 use parent -norequire => 'XML::Builder::Fragment';
 
 sub depends_ns_scope { 0 }
@@ -337,7 +337,7 @@ sub flatten { shift }
 #######################################################################
 
 package XML::Builder::Fragment::QName;
-$XML::Builder::Fragment::QName::VERSION = '0.905';
+$XML::Builder::Fragment::QName::VERSION = '0.906';
 use Object::Tiny::Lvalue qw( builder ns name as_qname as_attr_qname as_clarkname as_string );
 
 use parent -norequire => 'XML::Builder::Fragment';
@@ -414,7 +414,7 @@ sub foreach {
 #######################################################################
 
 package XML::Builder::Fragment::Tag;
-$XML::Builder::Fragment::Tag::VERSION = '0.905';
+$XML::Builder::Fragment::Tag::VERSION = '0.906';
 use parent -norequire => 'XML::Builder::Fragment';
 use Object::Tiny::Lvalue qw( qname attr );
 
@@ -452,7 +452,7 @@ sub flatten { shift }
 #######################################################################
 
 package XML::Builder::Fragment::Root;
-$XML::Builder::Fragment::Root::VERSION = '0.905';
+$XML::Builder::Fragment::Root::VERSION = '0.906';
 use parent -norequire => 'XML::Builder::Fragment::Tag';
 use overload '""' => 'as_string', fallback => 1;
 
@@ -476,7 +476,7 @@ sub as_string {
 #######################################################################
 
 package XML::Builder::Fragment::Document;
-$XML::Builder::Fragment::Document::VERSION = '0.905';
+$XML::Builder::Fragment::Document::VERSION = '0.906';
 use parent -norequire => 'XML::Builder::Fragment';
 use overload '""' => 'as_string', fallback => 1;
 
@@ -517,7 +517,7 @@ sub as_string {
 
 BEGIN {
 package XML::Builder::Util;
-$XML::Builder::Util::VERSION = '0.905';
+$XML::Builder::Util::VERSION = '0.906';
 use Carp::Clan '^XML::Builder(?:\z|::)';
 
 sub merge_param_hash {
@@ -557,7 +557,7 @@ XML::Builder - programmatic XML generation, conveniently
 
 =head1 VERSION
 
-version 0.905
+version 0.906
 
 =head1 DESCRIPTION
 
